==> hashikake-0.1.0.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/constants/AppColors.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
//	NAME:		AppColor.java
//	DATE:		2002.8.31
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.constants;

import java.awt.Color;

/**	
 *	AvP[V̐FǗNXB
 *	CX^X͂ȂiKvȂAłȂjB
 *	public萔ł̂ŁAgp͒ڃow肵ĂˁB
 */
public final class AppColors {
	/**	obNOEhJ[ */
	public static final Color BACK_COLOR = new Color(0, 160, 160);
	
	/**	ǂ̐F */
	public static final Color WALL_COLOR = new Color(0, 60, 60);
	
	/**	󔒏Ԃ̎̐F */
	public static final Color SPACE = Color.white;
	
	/**	̐F */
	public static final Color BRIDGE = Color.blue;
	
	/**	ZANeBuɂƂ̐F */
	public static final Color ACTIVE_COLOR = new Color(255, 25, 25, 127);
	
	/**	ANeBuɂƂ̐F */
	public static final Color ACTIVE_ISLAND = Color.blue;
	
	/**	ɏސ̐F */
	public static final Color ISLAND_NUMBER = Color.black;
	
	/**	̐F */
	public static final Color ISLAND = new Color(192, 192, 192, 127);
	
	private AppColors() {}
}

==> hashikake-0.4.3.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/constants/AppColors.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
//	NAME:		AppColor.java
//	DATE:		2002.8.31
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.constants;

import java.awt.Color;

/**	
 *	AvP[V̐FǗNXB
 *	CX^X͂ȂiKvȂAłȂjB
 *	public萔ł̂ŁAgp͒ڃow肵ĂˁB
 */
public final class AppColors {
	/**	obNOEhJ[ */
	public static final Color BACK_COLOR = new Color(0, 160, 160);
	
	/**	ǂ̐F */
	public static final Color WALL_COLOR = new Color(0, 60, 60);
	
	/**	󔒏Ԃ̎̐F */
	public static final Color SPACE = Color.white;
	
	/**	̐F */
	public static final Color BRIDGE = Color.blue;
	
	/**	ZANeBuɂƂ̐F */
	public static final Color ACTIVE_COLOR = new Color(255, 25, 25, 127);
	
	/**	ANeBuɂƂ̐F */
	public static final Color ACTIVE_ISLAND = Color.blue;
	
	/**	ɏސ̐F, ̐F */
	public static final Color ISLAND_NUMBER = Color.black;
	
	/**	ɏސ̐F, ̐F */
	public static final Color ISLAND = Color.lightGray;
	
	/** SolverˋłȂƂɎgp */
	public static final Color SOLVE_ILLEGAL_COLOR = Color.red;
	
	/** SolverɂĉˋˋiKłƂɎgp */
	public static final Color SOLVE_PROCESSING_COLOR = Color.orange;
	
	/** SolverˋƂɎgp */
	public static final Color SOLVE_FINISHED_COLOR = Color.green;
	
	private AppColors() {}
}
